package com.afp.ordermanagement.config;

import com.afp.ordermanagement.exception.BadAccessTokenException;
import com.afp.ordermanagement.service.ManagerTokenVerifier;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.web.server.ServerWebExchange;
import org.springframework.web.server.WebFilter;
import org.springframework.web.server.WebFilterChain;
import reactor.core.publisher.Mono;

@Component
public class AuthWebFilter implements WebFilter {
    @Autowired
    ManagerTokenVerifier managerTokenVerifier;

    @Override
    public Mono<Void> filter(ServerWebExchange serverWebExchange, WebFilterChain webFilterChain) {
        String path = serverWebExchange.getRequest().getPath().toString();

        if (!path.contains("/api/managers/")) return webFilterChain.filter(serverWebExchange);

        if (managerTokenVerifier.hasTokenHeader(serverWebExchange)) {
            String token = managerTokenVerifier.getTokenHeader(serverWebExchange);
            if (managerTokenVerifier.isTokenValid(token))
                return webFilterChain.filter(serverWebExchange);
        }

        return Mono.error(new BadAccessTokenException());
    }
}
